==> haskell-shelly-1.11.0-52-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-shelly.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 shelly
version:              1.11.0
visibility:           public
id:                   shelly-1.11.0-4z0q8u1hoty5U2Un6YSEtN
key:                  shelly-1.11.0-4z0q8u1hoty5U2Un6YSEtN
license:              BSD-3-Clause
maintainer:           Andreas Abel
author:               Greg Weber, Petr Rockai
homepage:             https://github.com/gregwebs/Shelly.hs
synopsis:             shell-like (systems) programming in Haskell
description:
    Shelly provides convenient systems programming in Haskell,
    similar in spirit to POSIX shells. Shelly:

    * is aimed at convenience and getting things done rather than
    being a demonstration of elegance,

    * has detailed and useful error messages,

    * maintains its own environment, making it thread-safe.

    Shelly is originally forked from the Shellish package.

    See the shelly-extra package for additional functionality.

    An overview is available in the README: <https://github.com/gregwebs/Shelly.hs/blob/master/README.md>

category:             Development
abi:                  c24c4da3148c5a7e0d3f22e4dad54cb7
exposed:              True
exposed-modules:      Shelly Shelly.Lifted Shelly.Pipe Shelly.Unix
hidden-modules:       Shelly.Base Shelly.Find Shelly.Directory
import-dirs:          /usr/lib/ghc-9.4.8/site-local/shelly-1.11.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/shelly-1.11.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/shelly-1.11.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-shelly
hs-libraries:         HSshelly-1.11.0-4z0q8u1hoty5U2Un6YSEtN
depends:
    async-2.2.5-BfPrxOOBs2Z6bEyvXKfM0q base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 directory-1.3.7.1
    enclosed-exceptions-1.0.3-3MnVekrzlsB51YBDZwNUsZ exceptions-0.10.5
    filepath-1.4.2.2 lifted-async-0.11.0-FSriAIzGpBC3AVqqoEY3lp
    lifted-base-0.2.3.12-CaZxFVx2QaKIfHbtq0tB6m
    monad-control-1.0.3.1-EMymL5qvPF86Ly30QNsrD5 mtl-2.2.2
    process-1.6.18.0 text-2.0.2 time-1.12.2 transformers-0.5.6.2
    transformers-base-0.4.6-C48guHuMOb9AOa55HXY0p9
    unix-compat-0.7.4.1-51QWcgHKY9Q2M4gdNfLh1f

haddock-interfaces:   /usr/share/doc/haskell-shelly/html/shelly.haddock
haddock-html:         /usr/share/doc/haskell-shelly/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-shelly-1.11.0-53-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-shelly.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 shelly
version:              1.11.0
visibility:           public
id:                   shelly-1.11.0-AP5EgwnW9bL1J16v24LPW
key:                  shelly-1.11.0-AP5EgwnW9bL1J16v24LPW
license:              BSD-3-Clause
maintainer:           Andreas Abel
author:               Greg Weber, Petr Rockai
homepage:             https://github.com/gregwebs/Shelly.hs
synopsis:             shell-like (systems) programming in Haskell
description:
    Shelly provides convenient systems programming in Haskell,
    similar in spirit to POSIX shells. Shelly:

    * is aimed at convenience and getting things done rather than
    being a demonstration of elegance,

    * has detailed and useful error messages,

    * maintains its own environment, making it thread-safe.

    Shelly is originally forked from the Shellish package.

    See the shelly-extra package for additional functionality.

    An overview is available in the README: <https://github.com/gregwebs/Shelly.hs/blob/master/README.md>

category:             Development
abi:                  5be5792a328c2c44280a599ef765a2ff
exposed:              True
exposed-modules:      Shelly Shelly.Lifted Shelly.Pipe Shelly.Unix
hidden-modules:       Shelly.Base Shelly.Find Shelly.Directory
import-dirs:          /usr/lib/ghc-9.4.8/site-local/shelly-1.11.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/shelly-1.11.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/shelly-1.11.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-shelly
hs-libraries:         HSshelly-1.11.0-AP5EgwnW9bL1J16v24LPW
depends:
    async-2.2.5-JGCoQdxZuXN6RYZ81Kl1U4 base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 directory-1.3.7.1
    enclosed-exceptions-1.0.3-5d5HkG9f42L9gkAITIDDVK exceptions-0.10.5
    filepath-1.4.2.2 lifted-async-0.11.0-LkkrF5EiVoL6SYDYJ9eFAr
    lifted-base-0.2.3.12-7CBBhkae1iy2FmbQDgCauu
    monad-control-1.0.3.1-69dnLrrVpTh4jQgsdou34S mtl-2.2.2
    process-1.6.18.0 text-2.0.2 time-1.12.2 transformers-0.5.6.2
    transformers-base-0.4.6-GqnHbqWDT0e8qlqX7fWzwX
    unix-compat-0.7.4.1-FHEkyK2HAgOIviNihEwrGS

haddock-interfaces:   /usr/share/doc/haskell-shelly/html/shelly.haddock
haddock-html:         /usr/share/doc/haskell-shelly/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
